@@ -93,7 +93,9 @@ def mid_feature_extraction(signal, sampling_rate, mid_window, mid_step,
 
     n_stats = 2
     n_feats = len(short_features)
-    mid_window_ratio = int(round(mid_window / short_step))
+    #mid_window_ratio = int(round(mid_window / short_step))
+    mid_window_ratio = round((mid_window -
+                              (short_window - short_step)) / short_step)
     mt_step_ratio = int(round(mid_step / short_step))
 
     mid_features, mid_feature_names = [], []
@@ -170,7 +172,7 @@ def directory_feature_extraction(folder_path, mid_window, mid_step,
         if sampling_rate == 0:
             continue        
 
-        t1 = time.clock()        
+        t1 = time.time()        
         signal = audioBasicIO.stereo_to_mono(signal)
         if signal.shape[0] < float(sampling_rate)/5:
             print("  (AUDIO FILE TOO SMALL - SKIPPING)")
@@ -205,7 +207,7 @@ def directory_feature_extraction(folder_path, mid_window, mid_step,
                 mid_term_features = mid_features
             else:
                 mid_term_features = np.vstack((mid_term_features, mid_features))
-            t2 = time.clock()
+            t2 = time.time()
             duration = float(len(signal)) / sampling_rate
             process_times.append((t2 - t1) / duration)
     if len(process_times) > 0:
@@ -324,16 +326,18 @@ def mid_feature_extraction_to_file(file_path, mid_window, mid_step,
     a) read the content of a WAV file
     b) perform mid-term feature extraction on that signal
     c) write the mid-term feature sequences to a np file
+    d) optionally write contents to csv file as well
+    e) optionally write short-term features in csv and np file
     """
     sampling_rate, signal = audioBasicIO.read_audio_file(file_path)
     signal = audioBasicIO.stereo_to_mono(signal)
+    mid_features, short_features, _ = \
+        mid_feature_extraction(signal, sampling_rate,
+                               round(sampling_rate * mid_window),
+                               round(sampling_rate * mid_step),
+                               round(sampling_rate * short_window),
+                               round(sampling_rate * short_step))
     if store_short_features:
-        mid_features, short_features, _ = \
-            mid_feature_extraction(signal, sampling_rate,
-                                   round(sampling_rate * mid_window),
-                                   round(sampling_rate * mid_step),
-                                   round(sampling_rate * short_window),
-                                   (sampling_rate * short_step))
         # save st features to np file
         np.save(output_file + "_st", short_features)
         if plot:
@@ -343,21 +347,15 @@ def mid_feature_extraction_to_file(file_path, mid_window, mid_step,
             np.savetxt(output_file + "_st.csv", short_features.T, delimiter=",")
             if plot:
                 print("Short-term CSV file: " + output_file + "_st.csv saved")
-    else:
-        mid_features, _, _ = \
-            mid_feature_extraction(signal, sampling_rate,
-                                   round(sampling_rate * mid_window),
-                                   round(sampling_rate * mid_step),
-                                   round(sampling_rate * short_window),
-                                   round(sampling_rate * short_step))
-        # save mt features to np file
-        np.save(output_file, mid_features)
+
+    # save mt features to np file
+    np.save(output_file + "_mt", mid_features)
+    if plot:
+        print("Mid-term np file: " + output_file + "_mt.npy saved")
+    if store_csv:
+        np.savetxt(output_file + "_mt.csv", mid_features.T, delimiter=",")
         if plot:
-            print("Mid-term np file: " + output_file + ".npy saved")
-        if store_csv:
-            np.savetxt(output_file + ".csv", mid_features.T, delimiter=",")
-            if plot:
-                print("Mid-term CSV file: " + output_file + ".csv saved")
+            print("Mid-term CSV file: " + output_file + "_mt.csv saved")
 
 
 def mid_feature_extraction_file_dir(folder_path, mid_window, mid_step,
