@@ -1,13 +1,22 @@
 from __future__ import print_function
 import math
 import numpy as np
+import sys
 from scipy.fftpack import fft
 import matplotlib.pyplot as plt
 from scipy.signal import lfilter
 from scipy.fftpack.realtransforms import dct
 from tqdm import tqdm
 
-eps = 0.00000001
+eps = sys.float_info.epsilon
+
+
+def dc_normalize(sig_array):
+    """Removes DC and normalizes to -1, 1 range"""
+    sig_array_norm = sig_array.copy()
+    sig_array_norm -= sig_array_norm.mean()
+    sig_array_norm /= abs(sig_array_norm).max() + 1e-10
+    return sig_array_norm
 
 
 def zero_crossing_rate(frame):
@@ -51,7 +60,12 @@ def spectral_centroid_spread(fft_magnitude, sampling_rate):
           (sampling_rate / (2.0 * len(fft_magnitude)))
 
     Xt = fft_magnitude.copy()
-    Xt = Xt / Xt.max()
+    Xt_max = Xt.max()
+    if Xt_max == 0:
+        Xt = Xt / eps
+    else:
+        Xt = Xt / Xt_max
+
     NUM = np.sum(ind * Xt)
     DEN = np.sum(Xt) + eps
 
@@ -286,7 +300,12 @@ def chroma_features(signal, sampling_rate, num_fft):
     # for i in range(12):
     #    finalC[i] = np.sum(C[i:C.shape[0]:12])
     final_matrix = np.matrix(np.sum(C2, axis=0)).T
-    final_matrix /= spec.sum()
+
+    spec_sum = spec.sum()
+    if spec_sum == 0:
+        final_matrix /= eps
+    else:
+        final_matrix /= spec_sum
 
     #    ax = plt.gca()
     #    plt.hold(False)
@@ -302,7 +321,8 @@ def chroma_features(signal, sampling_rate, num_fft):
     return chroma_names, final_matrix
 
 
-def chromagram(signal, sampling_rate, window, step, plot=False):
+def chromagram(signal, sampling_rate, window, step, plot=False,
+               show_progress=False):
     """
     Short-term FFT mag for spectogram estimation:
     Returns:
@@ -319,30 +339,24 @@ def chromagram(signal, sampling_rate, window, step, plot=False):
     step = int(step)
     signal = np.double(signal)
     signal = signal / (2.0 ** 15)
-    dc_offset = signal.mean()
-    maximum = (np.abs(signal)).max()
-    signal = (signal - dc_offset) / (maximum - dc_offset)
+    signal = dc_normalize(signal)
 
     num_samples = len(signal)  # total number of signals
-    cur_position = 0
     count_fr = 0
     num_fft = int(window / 2)
-    chromogram = np.array([], dtype=np.float64)
-
-    while cur_position + window - 1 < num_samples:
+    chromogram = np.zeros((int((num_samples-step-window) / step) + 1, 12),
+                          dtype=np.float64)
+    for cur_p in tqdm(range(window, num_samples - step, step),
+                      disable=not show_progress):
         count_fr += 1
-        x = signal[cur_position:cur_position + window]
-        cur_position = cur_position + step
+        x = signal[cur_p:cur_p + window]
         X = abs(fft(x))
         X = X[0:num_fft]
         X = X / len(X)
         chroma_names, chroma_feature_matrix = chroma_features(X, sampling_rate,
                                                               num_fft)
         chroma_feature_matrix = chroma_feature_matrix[:, 0]
-        if count_fr == 1:
-            chromogram = chroma_feature_matrix.T
-        else:
-            chromogram = np.vstack((chromogram, chroma_feature_matrix.T))
+        chromogram[count_fr-1, :] = chroma_feature_matrix.T
     freq_axis = chroma_names
     time_axis = [(t * step) / sampling_rate
                  for t in range(chromogram.shape[0])]
@@ -377,13 +391,13 @@ def spectrogram(signal, sampling_rate, window, step, plot=False,
     """
     Short-term FFT mag for spectogram estimation:
     Returns:
-        a np array (num_fft x numOfShortTermWindows)
+        a np array (numOfShortTermWindows x num_fft)
     ARGUMENTS:
-        signal:      the input signal samples
-        sampling_rate:          the sampling freq (in Hz)
+        signal:         the input signal samples
+        sampling_rate:  the sampling freq (in Hz)
         window:         the short-term window size (in samples)
-        step:        the short-term window step (in samples)
-        plot:        flag, 1 if results are to be ploted
+        step:           the short-term window step (in samples)
+        plot:           flag, 1 if results are to be ploted
         show_progress flag for showing progress using tqdm
     RETURNS:
     """
@@ -391,15 +405,13 @@ def spectrogram(signal, sampling_rate, window, step, plot=False,
     step = int(step)
     signal = np.double(signal)
     signal = signal / (2.0 ** 15)
-    dc_offset = signal.mean()
-    maximum = (np.abs(signal)).max()
-    signal = (signal - dc_offset) / (maximum - dc_offset)
+    signal = dc_normalize(signal)
 
     num_samples = len(signal)  # total number of signals
     count_fr = 0
     num_fft = int(window / 2)
-    specgram = np.array([], dtype=np.float64)
-
+    specgram = np.zeros((int((num_samples-step-window) / step) + 1, num_fft),
+                        dtype=np.float64)
     for cur_p in tqdm(range(window, num_samples - step, step),
                       disable=not show_progress):
         count_fr += 1
@@ -407,11 +419,7 @@ def spectrogram(signal, sampling_rate, window, step, plot=False,
         X = abs(fft(x))
         X = X[0:num_fft]
         X = X / len(X)
-
-        if count_fr == 1:
-            specgram = X ** 2
-        else:
-            specgram = np.vstack((specgram, X))
+        specgram[count_fr-1, :] = X
 
     freq_axis = [float((f + 1) * sampling_rate) / (2 * num_fft)
                  for f in range(specgram.shape[1])]
@@ -440,7 +448,7 @@ def spectrogram(signal, sampling_rate, window, step, plot=False,
         imgplot.set_cmap('jet')
         plt.colorbar()
         plt.show()
-
+    print(specgram.shape)
     return specgram, time_axis, freq_axis
 
 
@@ -448,10 +456,7 @@ def spectrogram(signal, sampling_rate, window, step, plot=False,
 def speed_feature(signal, sampling_rate, window, step):
     signal = np.double(signal)
     signal = signal / (2.0 ** 15)
-    dc_offset = signal.mean()
-    maximum = (np.abs(signal)).max()
-    signal = (signal - dc_offset) / maximum
-    # print (np.abs(signal)).max()
+    signal = dc_normalize(signal)
 
     num_samples = len(signal)  # total number of signals
     cur_p = 0
@@ -561,9 +566,8 @@ def feature_extraction(signal, sampling_rate, window, step, deltas=True):
     # signal normalization
     signal = np.double(signal)
     signal = signal / (2.0 ** 15)
-    dc_offset = signal.mean()
-    signal_max = (np.abs(signal)).max()
-    signal = (signal - dc_offset) / (signal_max + 0.0000000001)
+
+    signal = dc_normalize(signal)
 
     number_of_samples = len(signal)  # total number of samples
     current_position = 0
