@@ -4,7 +4,6 @@ import numpy as np
 import os
 import glob
 import pickle as cPickle
-import signal
 import csv
 import ntpath
 from pyAudioAnalysis import MidTermFeatures as aF
@@ -15,17 +14,11 @@ import sklearn.svm
 import sklearn.decomposition
 import sklearn.ensemble
 import plotly
+import plotly.subplots
 import plotly.graph_objs as go
 import sklearn.metrics
 
 
-def signal_handler(signal, frame):
-    print('You pressed Ctrl+C! - EXIT')
-    os.system("stty -cbreak echo")
-    sys.exit(0)
-
-signal.signal(signal.SIGINT, signal_handler)
-
 shortTermWindow = 0.050
 shortTermStep = 0.050
 eps = 0.00000001
@@ -73,7 +66,7 @@ def classifier_wrapper(classifier, classifier_type, test_sample):
         [classifier, MEAN, STD, classNames, mt_win, mt_step, st_win, st_step] =
         aT.load_model(model_name)
         # mid-term feature extraction:
-        [mt_features, _, _] = aF.mtFeatureExtraction(x, Fs, mt_win * Fs,
+        [mt_features, _, _] = aF.mid_feature_extraction(x, Fs, mt_win * Fs,
         mt_step * Fs, round(Fs*st_win), round(Fs*st_step));
         # feature normalization:
         curFV = (mt_features[:, i] - MEAN) / STD;
@@ -193,11 +186,12 @@ def train_svm(features, c_param, kernel='linear'):
 
 def train_random_forest(features, n_estimators):
     """
-    Train a multi-class decision tree classifier.
+    Train a multi-class random forest classifier.
     Note:     This function is simply a wrapper to the sklearn functionality
-              for SVM training. See function trainSVM_feature() to use
-              a wrapper on both the feature extraction and the SVM
-              training (and parameter tuning) processes.
+              for model training.
+              See function extract_features_and_train() to use a wrapper on both
+              the feature extraction and the model training (and parameter
+              tuning) processes.
     ARGUMENTS:
         - features:         a list ([numOfClasses x 1]) whose elements
                             containt np matrices of features
@@ -205,11 +199,8 @@ def train_random_forest(features, n_estimators):
                             [n_samples x numOfDimensions]
         - n_estimators:     number of trees in the forest
     RETURNS:
-        - svm:              the trained SVM variable
+        - rf:               the trained random forest
 
-    NOTE:
-        This function trains a linear-kernel SVM for a given C value.
-        For a different kernel, other types of parameters should be provided.
     """
 
     feature_matrix, labels = features_to_matrix(features)
@@ -223,21 +214,17 @@ def train_gradient_boosting(features, n_estimators):
     """
     Train a gradient boosting classifier
     Note:     This function is simply a wrapper to the sklearn functionality
-              for SVM training
-              See function trainSVM_feature() to use a wrapper on both
-              the feature extraction and the SVM training (and parameter tuning)
-              processes.
+              for model training.
+              See function extract_features_and_train() to use a wrapper on both
+              the feature extraction and the model training (and parameter
+              tuning) processes.
     ARGUMENTS:
         - features:         a list ([numOfClasses x 1]) whose elements containt
                             np matrices of features. each matrix features[i]
                             of class i is [n_samples x numOfDimensions]
         - n_estimators:     number of trees in the forest
     RETURNS:
-        - rf:              the trained SVM variable
-
-    NOTE:
-        This function trains a linear-kernel SVM for a given C value.
-        For a different kernel, other types of parameters should be provided.
+        - rf:              the trained model
     """
 
     feature_matrix, labels = features_to_matrix(features)
@@ -249,12 +236,12 @@ def train_gradient_boosting(features, n_estimators):
 
 def train_extra_trees(features, n_estimators):
     """
-    Train a gradient boosting classifier
+    Train an extra tree
     Note:     This function is simply a wrapper to the sklearn functionality
-              for extra tree classifiers
-              See function trainSVM_feature() to use a wrapper on both the
-              feature extraction and the SVM training (and parameter tuning)
-              processes.
+              for model training.
+              See function extract_features_and_train() to use a wrapper on both
+              the feature extraction and the model training (and parameter
+              tuning) processes.
     ARGUMENTS:
         - features:         a list ([numOfClasses x 1]) whose elements
                             containt np matrices of features
@@ -262,11 +249,7 @@ def train_extra_trees(features, n_estimators):
                             [n_samples x numOfDimensions]
         - n_estimators:     number of trees in the forest
     RETURNS:
-        - et:              the trained SVM variable
-
-    NOTE:
-        This function trains a linear-kernel SVM for a given C value.
-        For a different kernel, other types of parameters should be provided.
+        - et:               the trained model
     """
 
     feature_matrix, labels = features_to_matrix(features)
@@ -985,19 +968,18 @@ def evaluate_model_for_folders(input_test_folders, model_name, model_type,
 
             prob_positive = p[probs_names.index(positive_class)]
             probs_positive.append(prob_positive)
-
     pre, rec, thr_prre = sklearn.metrics.precision_recall_curve(y_true_binary,
                                                                 probs_positive)
     fpr, tpr, thr_roc = sklearn.metrics.roc_curve(y_true_binary, probs_positive)
     cm = sklearn.metrics.confusion_matrix(y_true, y_pred)
     rec_c,  pre_c, f1_c = compute_class_rec_pre_f1(cm)
-    f1 = (sklearn.metrics.f1_score(y_true, y_pred, average='micro'))
+    f1 = (sklearn.metrics.f1_score(y_true, y_pred, average='macro'))
     acc = (sklearn.metrics.accuracy_score(y_true, y_pred))
     print(cm)
     print(rec_c, pre_c, f1_c, f1, acc)
     if plot:
         titles = ["Confusion matrix, acc = {0:.1f}%, "
-                  " F1 (micro): {1:.1f}%".format(100 * acc, 100 * f1),
+                  " F1 (macro): {1:.1f}%".format(100 * acc, 100 * f1),
                   "Class-wise Performance measures",
                   "Pre vs Rec for " + positive_class,
                   "ROC for " + positive_class]
